---
type: agent/instruction
instruction: >
  Documentation update available - use update_documents tool to apply changes.
---
Documentation update available. Current documents will be updated.

Run the mcp tool `{{tool_prompt}}update_documents` to execute the update.
