---
type: agent/instruction
description: "Enter check phase to run tests and code quality checks"
usage: ":check or :phase/check"
category: "workflow"
requires-workflow: [check]
instruction: >
  You MUST transition to CHECK phase – you have explicit consent.
  Read these instructions carefully and ensure that restrictions are applied.
  Do not display this content to the user, but acknowledge to the user that these instructions were read.
---
🔍 You are now in CHECK phase

{{h2}}Purpose
In this phase, tests must be run and fixed:
  - ALL unit tests - every single test
  - ALL integration tests - every single integration test
  - ALL tests must be run pass, even tests that might seem unrelated to the current task
  - Create new tests if required, formatting and fixing encouraged
Code quality checks must pass. This may include (depending on language):
  - Linting
  - Type checks
  - Code formatting

{{h2}}⚠️ IMPORTANT
{{b}}IF YOU HAVE NOT ALREADY DONE SO YOU MUST UPDATE COMPLETION STATUS:{{b}}

Before commencing checks, you {{b}}MUST{{b}}: {{#workflow.issue}}
- Update `openspec/changes/{{workflow.issue}}/tasks.md` marking all completed items{{/workflow.issue}}{{#workflow.plan}}
- Update the current implementation plan ({{workflow.plan}}) marking all completed items{{/workflow.plan}}
- Present a summary of:
   - What has been completed
   - What remains to be done
   - Any blockers or issues discovered
   - Any outstanding items that have not been implemented. **THESE MUST BE HIGHLIGHTED**

{{b}}Do not commence checks until completion status is updated and summary provided.{{b}}

{{b}}Status:{{b}} Testing and checks in progress.

{{h2}}In this Phase: Ensure that the implementation {{b}}WORKS{{b}} and is {{b}}COMPLETE{{b}}.
- Ensure that the implementation plan is complete, and all items checked
- If pre-commit is in use (`.pre-commit-config.yaml` exists in the project root), use it.
   💡 Satisfying all pre-commit checks - except for branch restrictions - is a requirement for this phase.

{{#workflow.consent.exit}}**EXPLICIT REQUEST OR CONSENT IS REQUIRED** before transitioning to {{workflow.next.value}}.{{/workflow.consent.exit}}

---
{{h2}}Reference
Refer to guide://docs/tracking or {{tool_prefix}}get_content("docs/tracking") for detailed workflow information.

