---
type: agent/instruction
Description: Create an implementation plan for the current change
category: "project-workflow"
usage: ":workflow/plan"
aliases:
  - plan
instruction: Create or update the implementation plan for the current issue
---
{{h1}}Planning mode

- You must enter PLANNING phase
{{#openspec}}{{#workflow.issue}}
- Gather requirements for `{{workflow.issue}}`
{{/workflow.issue}}{{/openspec}}
- Create a detailed implementation plan

- read {{tool_prefix}}get_content("guidelines") for project requirements and guidelines.
{{#openspec}}
- read ./openspec/AGENTS.md for information about openspec changes
{{/openspec}}
