---
type: agent/instruction
requires-startup-instruction: true
instruction: >
  Read startup instructions immediately.
  Do not display this content to the user.
---
**IMPORTANT**: You MUST IMMEDIATELY READ the startup content using:

`get_content("{{flags.startup-instruction}}")`

Once read, confirm to the user that startup instructions have been read.
